@@ -1,11 +1,10 @@
 import pkg_resources
 
-from .model_parameter import ModelParameter
-from .model_info import ModelInfo
-from .modelmetadata import ModelMetadata
 from .errors import MetadataNotFoundError
-from .utils import install_mmd, get_cmdclass, get_entry_points
-
+from .model_info import ModelInfo
+from .model_parameter import ModelParameter
+from .modelmetadata import ModelMetadata
+from .utils import get_cmdclass, get_entry_points, install_mmd
 
 __version__ = pkg_resources.get_distribution("model_metadata").version
 __all__ = [
